@@ -21,8 +21,8 @@ import Hledger.Utils
 import Hledger.Data
 import Hledger.Query
 import Hledger.Reports
-import Hledger.Cli.Options
-import Hledger.Web.Options
+import Hledger.Cli.CliOptions
+import Hledger.Web.WebOptions
 
 -------------------------------------------------------------------------------
 -- Common page layout
