@@ -3,6 +3,7 @@
 
 module Handler.JournalR where
 
+import Data.Text (pack)
 import Import
 
 import Handler.AddForm
@@ -12,8 +13,8 @@ import Hledger.Data
 import Hledger.Query
 import Hledger.Reports
 import Hledger.Utils
-import Hledger.Cli.Options
-import Hledger.Web.Options
+import Hledger.Cli.CliOptions
+import Hledger.Web.WebOptions
 
 -- | The formatted journal view, with sidebar.
 getJournalR :: Handler Html
@@ -34,7 +35,7 @@ getJournalR = do
   hledgerLayout vd "journal" [hamlet|
        <h2#contenttitle>#{title}
        <!-- p>Journal entries record movements of commodities between accounts. -->
-       <a#addformlink role="button" style="cursor:pointer;" data-toggle="modal" data-target="#addmodal"  title="Add a new transaction to the journal" style="margin-top:1em;">Add a transaction
+       <a#addformlink role="button" style="cursor:pointer;" onClick="addformReset(true);" data-toggle="modal" data-target="#addmodal"  title="Add a new transaction to the journal" style="margin-top:1em;">Add a transaction
        ^{maincontent}
      |]
 
@@ -71,7 +72,7 @@ $forall p' <- tpostings t
   <td.description>
   <td.account>
    &nbsp;
-   <a href="/register?q=inacct:'#{paccount p'}'##{date}" title="#{paccount p'}">#{elideAccountName 40 $ paccount p'}
+   <a href="@?{acctlink (paccount p')}##{date}" title="#{paccount p'}">#{elideAccountName 40 $ paccount p'}
   <td.amount style="text-align:right;">#{mixedAmountAsHtml $ pamount p'}
 <tr.#{evenodd}>
  <td>&nbsp;
@@ -80,6 +81,7 @@ $forall p' <- tpostings t
  <td>
 |]
      where
+       acctlink a = (RegisterR, [("q", pack $ accountQuery a)])
        evenodd = if even n then "even" else "odd" :: String
        -- datetransition | newm = "newmonth"
        --                | newd = "newday"
