@@ -32,7 +32,7 @@ import Prelude hiding (putStrLn)
 import Hledger
 import Hledger.Utils.UTF8IOCompat (putStrLn)
 import Hledger.Cli hiding (progname,prognameandversion)
-import Hledger.Web.Options
+import Hledger.Web.WebOptions
 
 
 main :: IO ()
@@ -52,9 +52,15 @@ runWith opts
 
 withJournalDo' :: WebOpts -> (WebOpts -> Journal -> IO ()) -> IO ()
 withJournalDo' opts cmd = do
-  -- XXX head should be safe for now
-  (head `fmap` journalFilePathFromOpts (cliopts_ opts)) >>= readJournalFile Nothing Nothing True >>=
-    either error' (cmd opts . journalApplyAliases (aliasesFromOpts $ cliopts_ opts))
+  f <- head `fmap` journalFilePathFromOpts (cliopts_ opts) -- XXX head should be safe for now
+
+  -- https://github.com/simonmichael/hledger/issues/202
+  -- -f- gives [Error#yesod-core] <stdin>: hGetContents: illegal operation (handle is closed) for some reason
+  -- Also we may be writing to this file. Just disallow it.
+  when (f == "-") $ error' "hledger-web doesn't support --f -, please specify a file path"
+
+  readJournalFile Nothing Nothing True f >>=
+   either error' (cmd opts . journalApplyAliases (aliasesFromOpts $ cliopts_ opts))
 
 -- | The web command.
 web :: WebOpts -> Journal -> IO ()
@@ -63,21 +69,21 @@ web opts j = do
   let j' = filterJournalTransactions (queryFromOpts d $ reportopts_ $ cliopts_ opts) j
       p = port_ opts
       u = base_url_ opts
-      staticRoot' = pack <$> static_root_ opts
+      staticRoot = pack <$> file_url_ opts
   _ <- printf "Starting web app on port %d with base url %s\n" p u
   app <- makeApplication opts j' AppConfig{appEnv = Development
                                           ,appPort = p
                                           ,appRoot = pack u
                                           ,appHost = fromString "*4"
-                                          ,appExtra = Extra "" Nothing staticRoot'
+                                          ,appExtra = Extra "" Nothing staticRoot
                                           }
   if server_ opts
    then do
     putStrLn "Press ctrl-c to quit"
     hFlush stdout
-    runSettings (setPort p defaultSettings) app
+    Network.Wai.Handler.Warp.runSettings (setPort p defaultSettings) app
    else do
     putStrLn "Starting web browser if possible"
     putStrLn "Web app will auto-exit after a few minutes with no browsers (or press ctrl-c)"
     hFlush stdout
-    runUrlPort p "" app
+    Network.Wai.Handler.Launch.runUrlPort p "" app
